#
# spec file for package git-bug
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-bug
Version:        0.8.0+git.1733745604.d499b6e
Release:        3.1
Summary:        Distributed, offline-first bug tracker embedded in git, with bridges
License:        MIT
URL:            https://github.com/MichaelMure/git-bug
# Source0:        https://github.com/MichaelMure/%%{name}/archive/refs/tags/v%%{version}.tar.gz#/git-bug-%%{version}.tar.gz
Source0:        git-bug-%{version}.tar.gz
Source1:        vendor.tar.gz
# PATCH-FIX-UPSTREAM remote-config.patch gh#MichaelMure/git-bug!1076 mcepl@suse.com
# try reading git-bug.remote config value before defaulting to 'origin' when no explicit REMOTE argument
Patch0:         remote-config.patch
# PATCH-FIX-UPSTREAM CVE-2024-45337-bump-go-crypto.patch bsc#1234565 mcepl@suse.com
# bump golang.org/x/crypto from v0.26.0 to v0.31.0
Patch1:         CVE-2024-45337-bump-go-crypto.patch
BuildRequires:  golang(API) = 1.22
# # PATCH-FEATURE-UPSTREAM 501-export.patch gh#MichaelMure/git-bug!501 mcepl@suse.com
# # add a command to export bugs as raw operations
# Patch0:         501-export.patch
BuildRequires:  golang-packaging
BuildRequires:  git

%description
git-bug is a bug tracker that:

* is fully embedded in git: you only need your git repository to have
  a bug tracker
* is distributed: use your normal git remote to collaborate, push and
  pull your bugs!
* works offline: in a plane or under the sea? Keep reading and
  writing bugs!
* prevents vendor lock-in: your usual service is down or went bad?
  You already have a full backup.
* is fast: listing bugs or opening them is a matter of
  milliseconds
* doesn't pollute your project: no files are added in your
  project
* integrates with your tooling: use the UI you like (CLI,
  terminal, web) or integrate with your existing tools through
  the CLI or the GraphQL API
* bridges to other bug trackers: use bridges to import and export
  to other trackers.

%package bash-completion
Summary:        Bash completion for git-bug
Requires:       bash-completion
Requires:       %{name} = %{version}
Supplements:    (git-bug and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash shell completions for git-bug

%package fish-completion
Summary:        Fish completion for git-bug
Requires:       fish
Requires:       %{name} = %{version}
Supplements:    (git-bug and fish)
BuildArch:      noarch

%description fish-completion
Fish shell completions for git-bug

%package zsh-completion
Summary:        ZSH completion for git-bug
Group:          Productivity/File utilities
Requires:       zsh
Requires:       %{name} = %{version}
Supplements:    (git-bug and zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for git-bug

%prep
%autosetup -p1 -a1

%build
%make_build build

%install
install -Dm755 git-bug %{buildroot}%{_bindir}/git-bug
install -Dm644 -t %{buildroot}%{_mandir}/man1/ doc/man/*

# shell completions
install -Dm0644 misc/completion/bash/git-bug  \
    %{buildroot}%{_datadir}/bash-completion/completions/git-bug
install -Dm0644 misc/completion/fish/git-bug  \
    %{buildroot}%{_datadir}/fish/vendor_completions.d/git-bug.fish
install -Dm0644 misc/completion/zsh/git-bug  \
    %{buildroot}%{_sysconfdir}/zsh_completion.d/git-bug

%check
# before we mark network requiring tests (gh#git-bug/git-bug#1313)
%make_build test || true

%files
%license LICENSE
%doc README.md
%{_bindir}/git-bug
%{_mandir}/man1/git*.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/git-bug

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/git-bug.fish

%files zsh-completion
%dir %{_sysconfdir}/zsh_completion.d
%config %{_sysconfdir}/zsh_completion.d/git-bug

%changelog
* Wed Jan 22 2025 Matej Cepl <mcepl@cepl.eu>
- Add missing Requires to completion subpackages.
* Wed Jan  8 2025 Matej Cepl <mcepl@cepl.eu>
- Update vendorization.
* Tue Dec 17 2024 Matej Cepl <mcepl@cepl.eu>
- Update to version 0.8.0+git.1733745604.d499b6e:
  * fix typos in docs (#1266)
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.5.0 to 5.6.0 (#1289)
- Add CVE-2024-45337-bump-go-crypto.patch to bump
  golang.org/x/crypto from v0.26.0 to v0.31.0 (fix for
  CVE-2024-45337, bsc#1234565).
* Thu Oct  3 2024 mcepl@cepl.eu
- Update to version 0.8.0+git.1725552198.b0cc690:
  * build(deps): bump golang.org/x/term from 0.23.0 to 0.24.0 (#1261)
  * graphql: properly namespace Bug to make space for other entities (#1254)
  * refactor: rename github test repository: test-github-bridge (#1256)
  * build(deps-dev): bump the npm_and_yarn group across 1 directory with 4 updates (#1250)
  * core: make label a common type, in a similar fashion as for status (#1252)
  * chore: regenerate command completion and documentation (#1253)
  * feat: update references to the git-bug organization (#1249)
  * build(deps): bump github.com/vbauerster/mpb/v8 from 8.7.5 to 8.8.2 (#1248)
  * build(deps): bump golang.org/x/sys from 0.23.0 to 0.24.0 (#1242)
  * feat: add package to dev shell: delve (#1240)
  * build(deps): bump golang.org/x/crypto from 0.25.0 to 0.26.0 (#1239)
  * build(deps): bump golang.org/x/text from 0.16.0 to 0.17.0 (#1237)
  * feat(ci): support a merge queue
  * DOC: it is "new" not "configure" command (also was missing \)
  * build(deps): bump golang.org/x/sys from 0.22.0 to 0.23.0
  * build(deps): bump golang.org/x/oauth2 from 0.21.0 to 0.22.0
  * build(deps): bump golang.org/x/sync from 0.7.0 to 0.8.0
  * fix: correct path for reusable workflow: lifecycle
  * feat: merge go directive and toolchain specification
  * feat: improved lifecycle management with stale-bot
  * build(deps): bump github.com/vbauerster/mpb/v8 from 8.7.4 to 8.7.5
  * revert: "feat: increase operations per run for workflow: cron"
  * chore: update go dependencies
  * fix: run the presubmit pipeline for PRs
  * chore: remove refs to deprecated io/ioutil
  * fix: move codeql into an independent workflow
  * feat: bump node versions to 16.x, 18.x, and 20.x
  * feat: refactor pipelines into reusable workflows
  * build(deps): bump jsonwebtoken and @graphql-tools/prisma-loader
  * build(deps-dev): bump tough-cookie from 4.1.2 to 4.1.3 in /webui
  * build(deps): bump github.com/xanzy/go-gitlab from 0.106.0 to 0.107.0
  * build(deps): bump graphql from 16.6.0 to 16.8.1 in /webui
  * build(deps-dev): bump undici from 5.11.0 to 5.28.4 in /webui
  * build(deps): bump @babel/traverse from 7.19.3 to 7.24.8 in /webui
  * build(deps): bump github.com/99designs/gqlgen from 0.17.36 to 0.17.49
  * build(deps): bump github.com/dvsekhvalnov/jose2go from 1.5.0 to 1.6.0
  * build(deps-dev): bump semver from 5.7.1 to 5.7.2 in /webui
  * build(deps-dev): bump word-wrap from 1.2.3 to 1.2.5 in /webui
  * build(deps-dev): bump express from 4.18.1 to 4.19.2 in /webui
  * build(deps-dev): bump ws from 7.5.9 to 7.5.10 in /webui
  * build(deps): bump golang.org/x/vuln from 1.1.2 to 1.1.3
  * build(deps): bump github.com/go-git/go-git/v5 from 5.8.1 to 5.12.0
  * build(deps-dev): bump undici from 5.11.0 to 5.26.3 in /webui
  * build(deps): bump github.com/vbauerster/mpb/v8 from 8.5.2 to 8.7.4
  * build(deps): bump webpack from 5.74.0 to 5.76.1 in /webui
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.4.1 to 5.5.0
  * build(deps): bump ua-parser-js from 0.7.31 to 0.7.33 in /webui
  * build(deps): bump github.com/vektah/gqlparser/v2 from 2.5.15 to 2.5.16
  * build(deps): bump google.golang.org/protobuf from 1.31.0 to 1.33.0
  * build(deps): bump json5 from 1.0.1 to 1.0.2 in /webui
  * build(deps): bump loader-utils from 2.0.2 to 2.0.4 in /webui
  * build(deps): bump minimatch and recursive-readdir in /webui
  * fix: add write for prs: stale/issue-and-pr
  * feat: allow for manual execution of workflow: cron
  * feat: increase operations per run for workflow: cron
  * fix: add missing `with` property to //.github/workflows:cron.yml
  * feat: add workflow for triaging stale issues and prs
  * feat: add initial editorconfig configuration file
  * feat: add a common file for git-blame ignored revisions
  * feat: add a commit message template
  * feat: add initial nix development shell
  * feat: update action library versions
  * feat: add concurrency limits to all pipelines
  * fix: bump to go v1.22.5
  * fix: correct typo: acceps => accepts
  * build(deps): bump github.com/fatih/color from 1.16.0 to 1.17.0 (#1183)
  * build(deps): bump github.com/gorilla/mux from 1.8.0 to 1.8.1 (#1181)
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.1 (#1179)
  * build(deps): bump golang.org/x/vuln from 1.0.0 to 1.1.2 (#1171)
  * build(deps): bump golang.org/x/crypto from 0.21.0 to 0.25.0 (#1175)
  * build(deps): bump github.com/hashicorp/golang-lru/v2 from 2.0.5 to 2.0.7 (#1113)
  * build(deps): bump golang.org/x/text from 0.14.0 to 0.16.0 (#1173)
  * build(deps): bump github.com/vektah/gqlparser/v2 from 2.5.8 to 2.5.15 (#1164)
  * build(deps): bump github.com/hashicorp/go-retryablehttp (#1162)
  * build(deps): bump golang.org/x/net from 0.14.0 to 0.23.0 (#1166)
  * build(deps): bump golang.org/x/oauth2 from 0.11.0 to 0.21.0 (#1165)
  * build(deps): bump github.com/xanzy/go-gitlab from 0.90.0 to 0.106.0 (#1167)
  * build(deps): bump golang.org/x/sys from 0.11.0 to 0.14.0 (#1132)
* Sat Aug  3 2024 Matej Cepl <mcepl@cepl.eu>
- Add remote-config.patch (gh#MichaelMure/git-bug!1076): try
  reading git-bug.remote config value before defaulting to
  'origin' when no explicit REMOTE argument.
* Tue May  7 2024 mcepl@cepl.eu
- Update to version 0.8.0+git.1713935544.6d051a2:
  * Fix some comments
  * Update README.md
  * chore: fix some struct names in comments
  * Use HTTPS repo url
* Thu Mar 21 2024 mcepl@cepl.eu
- Update to version 0.8.0+git.1697403397.1212f75:
  * Fix typo
  * fix openpgp handling to sign/check
  * codespell: more ignore
  * api/graphql: regenerate after gqlgen upgrade
  * build(deps): bump github.com/99designs/gqlgen from 0.17.20 to 0.17.36
  * build(deps): bump github.com/99designs/gqlgen from 0.17.20 to 0.17.36
  * regenerate after cobra update
  * update to golang-lru v2
  * build(deps): bump github.com/hashicorp/golang-lru from 0.5.4 to 1.0.2
  * build(deps): bump golang.org/x/oauth2 from 0.8.0 to 0.11.0
  * build(deps): bump github.com/mattn/go-isatty from 0.0.17 to 0.0.19
  * build(deps): bump golang.org/x/sync from 0.1.0 to 0.3.0
  * build(deps): bump github.com/fatih/color from 1.13.0 to 1.15.0
  * build(deps): bump golang.org/x/vuln
  * build(deps): bump github.com/spf13/cobra from 1.6.1 to 1.7.0
  * build(deps): bump github.com/cloudflare/circl from 1.3.1 to 1.3.3
  * build(deps): bump golang.org/x/crypto from 0.5.0 to 0.12.0
  * build(deps): bump github.com/vbauerster/mpb/v8 from 8.1.4 to 8.5.2
  * codespell: no "with" means using codespellrc, add more opt out
  * build(deps): bump golang.org/x/term from 0.8.0 to 0.11.0
  * build(deps): bump golang.org/x/sys from 0.8.0 to 0.11.0
  * build(deps): bump golang.org/x/text from 0.9.0 to 0.12.0
  * build(deps): bump github.com/xanzy/go-gitlab from 0.79.1 to 0.90.0
  * build(deps): bump github.com/stretchr/testify from 1.8.1 to 1.8.4
  * build(deps): bump golang.org/x/oauth2 from 0.4.0 to 0.8.0
  * execenv: fix some cache building progress bar artifact
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.4.0 to 5.4.1
  * util: better IsRunning(pid)
  * webui: also teardown cleanly on SIGTERM
  * build(deps): bump golang.org/x/net from 0.5.0 to 0.7.0
  * CI: ignore spelling mistake in repo to be imported from github
  * tools: fix how security tools are setup and launched
  * repo: improve support for gitdir indirection
  * build(deps): bump github.com/xanzy/go-gitlab from 0.78.0 to 0.79.1
  * add more ideas in the feature matrix
  * cache: faster indexing by caping Bleve batch count
  * doc: add a feature matrix
  * chore: updated error message when detectGitPath fails
  * test: resolve changes for PR #1004, add unit test, fix issue uncovered by unit test
  * Add github workflow for codespell
  * [DATALAD RUNCMD] Run codespell -w
  * rudimentary codespell configuration
  * [DATALAD RUNCMD] Fix one ambigous overrided
  * build(deps): bump golang.org/x/oauth2 from 0.3.0 to 0.4.0
  * commands: add a helper to generate testing regex for CLI output
  * fix(#971): parse submodule .git files instead of erroring
  * docs(commands): try to make cleaned argument use more obvious
  * style: resolve PR comments
  * version: code cleanup, fix some edge cases
  * dirty should be bool
  * address PR review
  * commands: different pattern to detect changed flags
  * style: clean up linter complaints
  * build(deps): bump github.com/xanzy/go-gitlab from 0.77.0 to 0.78.0
  * fix(commands): replace missing import
  * fix(commands): create env.Env once for all Cobra commands
  * commands: remove compact style for "bug", as the width adaptive default renderer cover that usage
  * command: adapt the output of the bug list to the terminal size
  * execenv: move terminal detection to Out, introduce the compagnion In
  * feat: use isatty to detect a Termios instead
  * feat: detect os.Stdin/os.Stdout mode
  * New approach to define the version
  * build(deps): bump github.com/dustin/go-humanize from 1.0.0 to 1.0.1
  * repo: don't forget to close a file
  * repo: temporary use a fork of go-git due to https://github.com/go-git/go-git/pull/659
  * Fixed version info be set when go install
  * added EventMentionedInCommit
  * add wipe sub-command that remove local bugs and identities
  * commands: add a nice terminal progress bar when building the cache
  * properly close files in edge cases in various places
  * repo: check error when closing a repo in tests
  * make go1.19 fmt happy
  * cache: fix tests?
  * fix(commands): run tests in ./commands/... without ANSI color
  * build(deps): bump github.com/go-git/go-git/v5 from 5.5.1 to 5.5.2
  * chore(TestCache): cleanup per PR review
  * build(deps): bump golang.org/x/crypto from 0.4.0 to 0.5.0
  * build(deps): bump golang.org/x/text from 0.5.0 to 0.6.0
  * refactor(TestCache): guarantee test caches are closed when tests finish
  * fix(TestCache): eliminate hanging Windows tests
  * style(TestCache): remove empty trailing line from function
  * test(cache): close second instance of RepoCache
  * ci: use Go 1.19.4 and setup-go@v3
  * fix: resolve Go vulnerabilities
  * fix(972): use prerelease of GoKart with repaired panic
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.3.1 to 5.4.0
  * fix: keyrings must return keys with entities/identities
  * commands: share JSON creation
  * CI: remove lint security step as it's crashing
  * commands: don't double build the lamport clocks
  * build(deps): bump github.com/mattn/go-isatty from 0.0.16 to 0.0.17
  * feat: upgrade go-git to v5.1.1
  * commands: generic "select" code, move bug completion in bugcmd
  * cache: simplify cache building events handling
  * commands: move bug specific input code into commands/bug/input
  * cache: tie the last printf in an event to make the core print free
  * cache: fix some bugs after refactor
  * github: cleanup test token when test is done
  * cache: generic withSnapshot, some cleanup
  * cache: tie up the refactor up to compiling
  * repository: return specific error on object not found, accept multiple namespace to push/pull
  * build(deps): bump github.com/99designs/keyring from 1.2.1 to 1.2.2
  * WIP
  * repo: proper reduced interface for full-text indexing
  * WIP
  * doc/README: normalize verb tense and fix typo
  * build(deps): bump github.com/xanzy/go-gitlab from 0.76.0 to 0.77.0
  * build(deps): bump golang.org/x/text from 0.4.0 to 0.5.0
  * WIP
  * fix: remove repeated use of the same fmt.Errorf() calls
  * WIP
  * feat: wrap ErrMultipleConfigEntry to report duplicate key
  * feat: wrap ErrNoConfigEntry to report missing key
  * benchmark-action: make it work?
  * gha: add a workflow to continuously run benchmarks
  * build(deps): bump github.com/xanzy/go-gitlab from 0.74.0 to 0.76.0
  * commands: reorg into different packages
  * release: don't build for darwin/386 as support has been removed in golang
  * GHA: add a release workflow to build and upload binaries
  * webui: pack into binary
  * gogit: fix incorrect loader handling
  * github: sanitize rate limit waiting time
  * go-git: concurrent loading of clocks
  * github: fix rate limiting
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1
  * core: bubble up the comment ID when created, or edited the first comment
  * build(deps): bump github.com/xanzy/go-gitlab from 0.73.1 to 0.74.0
  * build(deps): bump golang.org/x/text from 0.3.7 to 0.4.0
* Sun Nov 20 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.8.0:
  - More than 800 commits and a long long time after, git-bug
    v0.8.0 is now available.
  - Once again, this release represent a push towards making
    git-bug generally useful and correct. The two main
    improvements are a new Entity framework and write-capable
    WebUI.
  - Breaking changes(openSUSE package is much closer to this
    release)
  - changes in the data model makes it a requirement to use the
    migration tool to to update any previous repo.
  - remove the legacy identities that were directly embedded in
    bugs
  - Core
  - introduce a reusable entity package capable of handling
    all the complex operations of an Entity (bug, board,
    config ...): operations, DAG manipulation, conflict merge,
    signature, integrity ... to greatly simplify writing and
    maintaining an entity. Documentation 1, Documentation 2
  - introduce CombinedId, a new kind of identifier for an
    item within an Entity (for example a comment in a bug),
    that hold two partial identifiers interleaved for fast
    addressing. Documentation
  - introduce the concept of resolvers, so that entities can
    link to another
  - use go-git to manipulate the git repository, instead of
    executing the local git binary
  - add support for signing the git commit with the author's
    signature, and verifying
  - add support for git config includes by @mindriot101
  - rework of the Repository layer for modularity, simplicity
    and testing, allowing more easily to plug an alternative
    storage
  - support for full text search in bug comments
  - support application namespace in the repository so that
    other app can use the entity package as a framework by
    @smoyer64
  - Commands
  - auto-completion of bug identifier, bridge names,
    credentials, labels, remote, identity and flags tada by
    @krobelus
  - complete refactoring to avoid global variables and be more
    conductive to testing
  - new command comment edit to edit a bug's comment
  - new command rm to remove a bug by @vincetiu8
  - ls and show learned different output format with
  - -format=<format>, with format being one of default, plain,
    json, compact and org-mode by @vincetiu8 and @karlicoss
  - allow user create without interactive prompt by
    @cvhariharan
  - Query language
  - support filtering on bugs having no labels
  - support filtering on metadata by @vmiklos
  - Bug
  - complete rework using the new entity framework
  - Cache
  - introduce a LRU to have a limit of entities loaded in
    memory and effectively cap the memory usage of long running
    processes by @vincetiu8
  - proper locking for concurrent access by @vincetiu8
  - Bridges
  - core: support for remote bug tracker rate limiting by
    @rng-dynamics
  - core: support to indicate that the configuration wizard is
    executed non-interactively and should have all the required
    parameters set by @GlancingMind
  - Github: revamped client and iterator with proper rate
    limiting handling by @rng-dynamics
  - Github: revamped credentials creation following Github
    removing the previous API by @rng-dynamics
  - Github: support new token format by @ellsclytn
  - Github: extended tests by @rng-dynamics
  - Github: fix push then pull creating duplicates by
    @rng-dynamics
  - Gitlab: revamped client to use the much better event API to
    replace the note API that was hard to use and caused a lot
    of problems and headaches by @5nord
  - Gitlab: fix access token settings by @remram44
  - Gitlab: cleanup titles on import by @vincetiu8
  - Gitlab: support new token format by @gaelj
  - Jira: fix incorrect client creation reusing the same
    credential
  - API
  - new HTTP handler to access files stored in git
  - new HTTP handler to upload a file to git
  - GraphQL
  - strong typing for identifiers
  - prepare for external authentication
  - introduce addCommentAndClose and addCommentAndReopen
    mutations, to comment and change a bug state in a single
    atomic operation by @GlancingMind
  - introduce editComment mutation to edit comments
  - TermUI
  - fix a crash when trying to open a bug when there are none
    by @vojta001
  - properly trim spaces in titles by @wavexx
  - make the help visually easier to parse
  - denser bug list view by @wavexx
  - fixed readability on bright terminal by @zdenek-crha
  - WebUI
  - now report GraphQL errors in the console when --log-errors
    is used
  - large refactoring to bring good practice and simplify
    future work by @sandhose
  - add support for read-only mode by @lukegb and
    @claudioantonio
  - support for creating bugs by @claudioantonio
  - support for closing and reopening bugs by @claudioantonio
  - allow to specify the host address when launching with
  - -host=<host> for easier hosting, in particular in
    container by @GlancingMind
  - allow specifying the initial query with --query by @vmiklos
  - dark mode by @GlancingMind
  - show count of comment on each bug in the list by
    @GlancingMind
  - improved navigation by @GlancingMind
  - comment edition and show edit history by @GlancingMind
  - bug list filtering by @GlancingMind
  - add user profile by @GlancingMind
  - show placeholder for empty comment preview by @GlancingMind
* Thu Nov  3 2022 mcepl@cepl.eu
- Update to version 0.7.2+git.1666446996.55a2e8e:
  * doc: fix incorrect indentation
* Mon Oct 17 2022 Matej Cepl <mcepl@suse.com>
- Fix Supplements tag for bash-completion subpackage.
* Mon Oct 17 2022 mcepl@cepl.eu
- Update to version 0.7.2+git.1665512451.0eef939:
  * makefile: better PHONY
  * webui: put react-scripts and typescript as dev-dependency
  * webui: update most of dependencies
  * build(deps): bump github.com/99designs/gqlgen from 0.17.17 to 0.17.20
  * fix: process unused (but assigned) error
  * fix(884): scan PRs for insecure practices
  * feat(530) make label commands consistent
  * test(863): fix test for full id instead of "human"
  * refactor(git-bug-863): merge ls-id into ls
  * build(deps): bump github.com/praetorian-inc/gokart from 0.4.0 to 0.5.1
  * build(deps): bump github.com/99designs/gqlgen from 0.17.13 to 0.17.17
  * fix: correct name for one of the security phonies
  * feat: run security checks during Go workflow
  * feat: add recipes for security analysis
  * fix: hide tools versioning behind build tags
  * feat: add security tools
  * feat: version tools using Go module system
  * generalized interface for an Entity
  * dag: test op serialisation with the unmarshaller, to allow resolving entities
  * fix(850): normalize Windows line endings -> *nix (golden files)
  * fix(850): normalize Windows line endings -> *nix
  * fix(850): merge in CombinedId from 664
  * webui: add a flag to log handling errors
  * build(deps): bump github.com/xanzy/go-gitlab from 0.72.0 to 0.73.1
  * webui: adapt to CombinedId
  * bug: have a type for combined ids, fix https://github.com/MichaelMure/git-bug/issues/653
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0
  * build(deps): bump github.com/xanzy/go-gitlab from 0.68.0 to 0.72.0
  * move bug.Status in entities/common for reuse
  * fix(850): remove obsolete test logging
  * tests(850): add tests for comment ls, add and edit
  * move {bug,identity} to /entities, move input to /commands
  * remove file that shouldn't be there
  * core: generalized resolvers to resolve any entity time when unmarshalling an operation
  * fix(836): revert to older test harness
  * feat(836): updates default ls formatter for TSV output
  * docs(847): add compact to docs and bash for ls command's format flag
  * build(deps): bump github.com/mattn/go-isatty from 0.0.14 to 0.0.16
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.8.0
  * build: go 1.18 minimum
  * bug: fix an issue where Id would be used, then changed due to metadata
  * entity/dag: proper base operation for simplified implementation
  * doc: more tiny fixes
  * doc: more tiny fixes
  * doc: tiny tweaks
  * test(809): do not export function that returns GoGit filesystem
  * test(809): remove reliance on repo's filesystem
  * test: use testing.TB as common interface
  * test(809): remove remaining calls to InitGoRepo in tests
  * refactor(809): eliminate need to defer CleanupTestRepos()
  * test(778): simplify and guarantee backend cleanup
  * refactor(778): test only command implementations
  * chore(808): rearrange imports to git-bug convention
  * test(808): document getCWD() and clean-up arguments
  * test(808): skip root help test that uses a golden file
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2
  * fix(808): remove duplication stderr/stdout set-up
  * test(808): make build tag compatible with Go 1.16
  * test(808): do not run golden file tests on Windows
  * fix(808): simplify handling of Windows line terminations
  * chore(808): merge in LocalStorage namespace configuration
  * fix(808): replace Windows line terminators
  * github: fix data race when closing event channel
  * graphql: fix two invalid mutex lock leading to data races
  * fix(778): remove extra mutex lock when resolving bug prefix
  * cache: ensure that the default repo has a non-empty name to make js/apollo happy
  * doc: more discoverable docs
  * misc: move all completions in a dedicated folder
  * refactor: simplify creation of temp dir - after 1.15
  * fix: remove only t.Parallel()
  * gogit: close index before deleting it on disk
  * test: clean up temp dir and repo correctly
  * test(778): execute rm bug in testEnv (hangs)
  * test(778): execute add user in testEnv and return userID
  * test(778): clear output after user creation
  * test(778): verify user create results in an identity and cache
  * test(778): verify root command returns main help text
  * test(778): allow alternate CWD via context
  * test(778): capture stderr and stdout during tests
  * test: add verification that localStorage.Root() resolves to the correct absolute filepath
  * refactor: use namespace instead of application of applicationName
  * chore: clean-up commented code
  * feat: make local storage configurable
  * build(deps): bump github.com/xanzy/go-gitlab from 0.64.0 to 0.68.0
  * model: Multiple, minor readability and language improvements
  * model: Removes now outdated statement about ops and root
  * model: Highlight some words with special meaning
  * model: Links to a section further down
  * model: Moves example description after the example
  * model: Adds link explaining nounce (wikipedia)
  * model: strict Markdown requires empty lines before (and after) lists
  * completion: lots of small ironing
  * ls: fix incorrect query parsing with quotes escaped by the shell
  * misc: fix bash completion with "git bug"
  * completion: use the correct GenBashCompletionV2 instead of the legacy function
  * Add command-specific argument completions
  * a few fixes
  * build(deps): bump github.com/xanzy/go-gitlab from 0.59.0 to 0.64.0
  * Allow new gitlab PAT format
  * entity/dag: add an extensive example
  * doc: add missing file
  * update doc
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1
  * bug: don't serialize multiple time the author, only once in OperationPack
  * jira: fix incorrect client creation reusing the same credential
  * update cobra to v1.4.0
  * Bump github.com/99designs/gqlgen from 0.16.0 to 0.17.1
  * build: require go 1.16
  * build(deps): bump github.com/99designs/keyring from 1.2.0 to 1.2.1
  * Bump github.com/vektah/gqlparser/v2 from 2.4.0 to 2.4.1
  * entity: allow to resolve identities when numashalling operations
  * Fix a bunch of comments and documentations
  * build(deps): bump github.com/xanzy/go-gitlab from 0.57.0 to 0.59.0
  * Bump github.com/xanzy/go-gitlab from 0.55.1 to 0.57.0 (#757)
  * webui: fix dark theme colors
  * webui: fix compile
  * CI: update nodejs
  * Bump github.com/vektah/gqlparser/v2 from 2.2.0 to 2.4.0
  * webui: replace GraphQL linter
  * webui: upgrade Material UI
  * webui: upgrade react-router
  * webui: replace React imports
  * webui: upgrade most dependencies
  * webui: upgrade graphql-codegen dependencies
  * Bump github.com/xanzy/go-gitlab from 0.54.3 to 0.55.1
  * update gocui
  * update keyring and migrate to github.com/ProtonMail/go-crypto
  * update gqlgen
  * Bump follow-redirects from 1.13.0 to 1.14.7 in /webui (#735)
  * Bump github.com/xanzy/go-gitlab from 0.54.1 to 0.54.3 (#734)
  * Bump github.com/spf13/cobra from 1.2.1 to 1.3.0 (#731)
  * Bump ws from 5.2.2 to 5.2.3 in /webui (#728)
  * Bump tmpl from 1.0.4 to 1.0.5 in /webui (#711)
  * Bump path-parse from 1.0.6 to 1.0.7 in /webui (#701)
  * Bump url-parse from 1.5.1 to 1.5.3 in /webui (#714)
  * Bump github.com/xanzy/go-gitlab from 0.50.4 to 0.54.1 (#732)
  * gitlab: re-enable previously broken test
  * gitlab: order events on the fly
  * Fix: github import, some issue titles cause error
  * Fix: github bridge: push then pull without duplication
  * Update URL of GitLab access token settings
  * Fix GitLab showing https:/../personal_access_token
  * Add scoop installation for Windows
  * Bump github.com/fatih/color from 1.12.0 to 1.13.0
  * Command ls: Add compact format
  * Add some documentation comments
  * gitlab: Add new iterator with state change events
* Mon Nov 29 2021 mcepl@cepl.eu
- Update to version 0.7.2+git.1632416688.1eaf3ec0:
  * Bump github.com/mattn/go-isatty from 0.0.13 to 0.0.14 (#709)
  * Tests for the github bridge (#706)
  * feature: Github bridge mutation rate limit (#694)
  * Add Linter Step (#698)
  * Bump golang.org/x/text from 0.3.6 to 0.3.7 (#702)
  * Bump github.com/xanzy/go-gitlab from 0.50.1 to 0.50.4 (#707)
  * Bump github.com/spf13/cobra from 1.1.3 to 1.2.1 (#695)
  * Bump github.com/go-git/go-git/v5 from 5.4.1 to 5.4.2 (#689)
  * Bump github.com/xanzy/go-gitlab from 0.50.0 to 0.50.1 (#693)
  * Bump dns-packet from 1.3.1 to 1.3.4 in /webui
* Sat Nov 27 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.7.2:
  - fixes a security issue (CVE-2021-28955) where arbitrary
    malicious code could be executed if someone commit a git
    executable inside the repository (reproducible only on
    Windows).
* Fri Jan 22 2021 Matej Cepl <mcepl@suse.com>
- Initial packaging of 0.7.1
